spannertools.destroy_spanners_attached_to_component
===================================================

.. autofunction:: abjad.tools.spannertools.destroy_spanners_attached_to_component.destroy_spanners_attached_to_component
   :noindex:
